@@ -1,6 +1,4 @@
-if (getRversion() >= "3.1.0") {
-  utils::globalVariables(".")
-}
+utils::globalVariables(".")
 
 ################################################################################
 #' Process a simulation event
@@ -793,7 +791,18 @@ setMethod(
 
     sim <- withCallingHandlers({
 
+      recoverModeWrong <- getOption("spades.recoverMode")
+      if (!is.null(recoverModeWrong))
+        warning("Please set options('recoveryMode') with a 'y', not options('recoverMode')")
+      recoverMode <- getOption("spades.recoveryMode", FALSE)
+
+      # If there already is a sim object saved in the .pkgEnv, it may have objects,
+      #   and those objects may have temporary files from file-backed objects stored.
+      #   This will remove those file-backed temp files
+      clearFileBackedObjs(.pkgEnv$.sim$.recoverableObjs, recoverMode)
       .pkgEnv$.sim <- NULL # Clear anything that was here.
+      .pkgEnv$.sim <- sim # set up pointer
+
       # set the options("spades.xxxPath") to the values in the sim@paths
       oldGetPaths <- getPaths()
       do.call(setPaths, append(sim@paths, list(silent = TRUE)))
@@ -825,12 +834,16 @@ setMethod(
       # Memory Use
       # memory estimation of each event/sim
       if (getOption("spades.memoryUseInterval", 0) > 0) {
+        if (requireNamespace("future", quietly = TRUE)) {
         originalPlan <- future::plan()
         sim <- memoryUseSetup(sim, originalPlan)
         # Do the on.exit stuff
         on.exit({
           sim <- memoryUseOnExit(sim, originalPlan)
         }, add = TRUE)
+        } else {
+          message(futureMessage)
+        }
       }
 
       # timeunits gets accessed every event -- this should only be needed once per simList
@@ -865,7 +878,7 @@ setMethod(
             sim = sim,
             reloadPkgs = getOption("spades.restartR.reloadPkgs", restartFormals$reloadPkgs),
             .First = getOption("spades.restartR..First", restartFormals$.First),
-            .RDataFile = getOption("spades.restartR.RDataFilename", sim$._restartRList$simFilename),
+            .RDataFile = getOption("spades.restartR.filename", sim$._restartRList$simFilename),
             restartDir = getOption("spades.restartR.restartDir", restartFormals$restartDir)
           )
         }
@@ -875,10 +888,8 @@ setMethod(
         if (!is.numeric(.plotInitialTime))
           .plotInitialTime <- as.numeric(.plotInitialTime)
         paramsLocal <- sim@params
-        whNonHiddenModules <-
-          !grepl(names(paramsLocal), pattern = "\\.")
-        paramsLocal[whNonHiddenModules] <-
-          lapply(paramsLocal[whNonHiddenModules], function(x) {
+        whNonHiddenModules <- !grepl(names(paramsLocal), pattern = "\\.")
+        paramsLocal[whNonHiddenModules] <- lapply(paramsLocal[whNonHiddenModules], function(x) {
             x$.plotInitialTime <- .plotInitialTime
             x
           })
@@ -941,11 +952,6 @@ setMethod(
           sim@completed <- new.env(parent = emptyenv())
       }
 
-      recoverModeWrong <- getOption("spades.recoverMode")
-      if (!is.null(recoverModeWrong))
-        warning("Please set options('recoveryMode') with a 'y', not options('recoverMode')")
-      recoverMode <- getOption("spades.recoveryMode", FALSE)
-
       if (recoverMode > 0) {
         rmo <- NULL # The recovery mode object
         allObjNames <- outputObjectNames(sim)
@@ -1074,8 +1080,7 @@ setMethod(
 })
 
 #' @keywords internal
-.runEvent <- function(sim, cacheIt, debug, moduleCall, fnEnv, cur, notOlderThan,
-                      showSimilar) {
+.runEvent <- function(sim, cacheIt, debug, moduleCall, fnEnv, cur, notOlderThan, showSimilar) {
   if (cacheIt) { # means that a module or event is to be cached
     createsOutputs <- sim@depends@dependencies[[cur[["moduleName"]]]]@outputObjects$objectName
     fns <- ls(fnEnv, all.names = TRUE)
@@ -1194,8 +1199,11 @@ recoverModePre <- function(sim, rmo = NULL, allObjNames = NULL, recoverMode) {
   if (length(rmo$randomSeed) > (recoverMode - 1))
     rmo$randomSeed <- rmo$randomSeed[seq_len(recoverMode - 1)]
   startTime <- Sys.time()
-  if (length(rmo$recoverableObjs) > (recoverMode - 1))
+  if (length(rmo$recoverableObjs) > (recoverMode - 1)) {
+    clearFileBackedObjs(rmo$recoverableObjs, recoverMode)
     rmo$recoverableObjs <- rmo$recoverableObjs[seq_len(recoverMode - 1)]
+  }
+
 
   if (length(sim@events) > 0) {
     objsInSimListAndModule <- ls(sim) %in% allObjNames[[sim@events[[1]][["moduleName"]]  ]]
@@ -1322,3 +1330,28 @@ setupDebugger <- function(debug = getOption("spades.debug")) {
 spadesDefaultFormatter <- function(record) {
   text <- paste(record$timestamp, paste(record$levelname, record$logger, gsub("\n$", "", record$msg), sep=':'), sep = "")
 }
+
+#' @importFrom reproducible Filenames
+clearFileBackedObjs <- function(recoverableObjs, recoverMode) {
+  if (isTRUE(recoverMode > 0)) {
+    toClear <- recoverableObjs[[as.numeric(recoverMode)]]
+    if (length(toClear)) {
+      out <- lapply(toClear, function(x) {
+        if (is(x, "Raster")) {
+          Filenames(x)
+        }
+      })
+      files <- unname(unlist(out))
+      files <- files[nzchar(files)]
+      if (length(files) != 0 ) {
+        unlink(files)
+        dirs <- unique(dirname(files))
+        filesLeft <- dir(dirs, full.names = TRUE)
+        if (length(filesLeft) == 0 || all(grepl("cache", filesLeft))) {
+          unlink(dirs, recursive = TRUE)
+        }
+      }
+    }
+  }
+  return(invisible())
+}
