@@ -422,8 +422,8 @@ test_that("Filenames for simList", {
   }, add = TRUE)
 
   s <- simInit()
-  s$r <- raster(extent(0,10,0,10), vals = 1, res = 1)
-  s$r2 <- raster(extent(0,10,0,10), vals = 1, res = 1)
+  s$r <- raster(extent(0, 10, 0, 10), vals = 1, res = 1)
+  s$r2 <- raster(extent(0, 10, 0, 10), vals = 1, res = 1)
   s$r <- writeRaster(s$r, filename = tmpfile[1], overwrite = TRUE)
   s$r2 <- writeRaster(s$r2, filename = tmpfile[3], overwrite = TRUE)
   s$s <- stack(s$r, s$r2)
@@ -431,13 +431,9 @@ test_that("Filenames for simList", {
 
   Fns <- Filenames(s)
 
-  fnsGrd <- c(filename(s$b), gsub("grd$", "gri", filename(s$b)))
-  if (length(Fns$b) == 1) {
-    expect_true(identical(Fns$b, fnsGrd[[1]])) ## TODO: it should never be length 1 -- solve this!
-  } else {
-    expect_true(identical(Fns$b, fnsGrd))
-  }
-  expect_true(identical(Fns$r, filename(s$r)))
-  expect_true(identical(Fns$r2, filename(s$r2)))
-  expect_true(identical(Fns$s, sapply(seq_len(nlayers(s$s)), function(rInd) filename(s$s[[rInd]]))))
+  fnsGrd <- normPath(c(filename(s$b), gsub("grd$", "gri", filename(s$b))))
+  expect_true(identical(Fns$b, fnsGrd))
+  expect_true(identical(Fns$r, normPath(filename(s$r))))
+  expect_true(identical(Fns$r2, normPath(filename(s$r2))))
+  expect_true(identical(Fns$s, sapply(seq_len(nlayers(s$s)), function(rInd) normPath(filename(s$s[[rInd]])))))
 })
