@@ -1,112 +1,113 @@
-# test_that("timeunit works correctly", {
-#   testInitOut <- testInit()
-#   on.exit({
-#     testOnExit(testInitOut)
-#   }, add = TRUE)
-#
-#   times <- list(start = 0.0, end = 10)
-#   params <- list(
-#     .globals = list(burnStats = "npixelsburned", stackName = "landscape"),
-#     randomLandscapes = list(.plotInitialTime = NA, .plotInterval = NA),
-#     caribouMovement = list(.plotInitialTime = NA, .plotInterval = NA),
-#     fireSpread = list(.plotInitialTime = NA, .plotInterval = NA)
-#   )
-#   modules <- list("randomLandscapes", "caribouMovement", "fireSpread")
-#   paths <- list(modulePath = system.file("sampleModules", package = "SpaDES.core"))
-#
-#   mySim <- simInit(times, params, modules, objects = list(), paths = paths)
-#
-#   expect_equal(maxTimeunit(sim = mySim), "year")
-#
-#   x1 <- list(
-#     name = "testModule",
-#     description = "this is a test.",
-#     keywords = c("test"),
-#     authors = c(person(c("Alex", "M"), "Chubaty",
-#                        email = "alexander.chubaty@canada.ca",
-#                        role = c("aut", "cre"))),
-#     version = list(testModule = "0.0.1"),
-#     spatialExtent = raster::extent(rep(NA_real_, 4)),
-#     timeframe = as.POSIXlt(c(NA, NA)),
-#     timeunit = NA_character_,
-#     citation = list(),
-#     reqdPkgs = list("grid", "raster", "sp"),
-#     parameters = rbind(
-#       defineParameter("dummyVal", "numeric", 1.0, NA, NA, "vague description")
-#     ),
-#     inputObjects = dplyr::bind_rows(
-#       expectsInput(objectName = "testInput", objectClass = "list", sourceURL = "", desc = NA_character_)
-#     ),
-#     outputObjects = dplyr::bind_rows(
-#       createsOutput(objectName = "testOutput", objectClass = "list", desc = NA_character_)
-#     )
-#   )
-#
-#   # Test for numerics, or character strings that are not recognized
-#   expect_message(timeunit(mySim) <- 1, "^unknown timeunit provided:")
-#   expect_message(timeunit(mySim) <- "LeapYear", "^unknown timeunit provided:")
-#
-#
-#   # check for new unit being put into simList
-#   assign("dfortnight", function(x) lubridate::duration(dday(14)),
-#          envir = envir(mySim))
-#   expect_match(timeunit(mySim) <- "fortnight", "")
-#   expect_match(timeunit(mySim), "fortnight")
-#   expect_equivalent(as.numeric(mySim$dfortnight(1)), 1209600)
-#   rm(dfortnight, envir = envir(mySim))
-#
-#   # test that NA_real_ gets coerced to NA_character_
-#   timeunit(mySim) <- NA_real_
-#   expect_identical(timeunit(mySim), NA_character_)
-#
-#   # check that the minTimeunit captures one of the timestepUnits in the loaded modules
-#   expect_true(
-#     any(match(minTimeunit(mySim),
-#               sapply(depends(mySim)@dependencies, function(x) {
-#                 x@timeunit
-#               })
-#              )
-#        )
-#   )
-#
-#   # check that minTimeunit finds the smallest timeunit of the modules loaded
-#   whNotNA <- sapply(depends(mySim)@dependencies,
-#                     function(x) !is.na(x@timeunit))
-#   expect_equivalent(as.numeric(eval(parse(
-#     text = paste0("d", minTimeunit(mySim), "(1)")))),
-#     min(sapply(depends(mySim)@dependencies[whNotNA],
-#                function(x) {
-#                  eval(parse(text = paste0("d", x@timeunit, "(1)")))
-#                }
-#     )))
-#   expect_equal(as.numeric(inSeconds(NA_character_)), 0)
-#   expect_equal(as.numeric(inSeconds(NULL)), 0)
-#
-#   exampleTime <- 1:10
-#   attributes(exampleTime)$unit <- NA_character_
-#   expect_equal(as.numeric(convertTimeunit(exampleTime, "seconds")),
-#                rep(0, length(exampleTime)))
-#
-#   exampleTime <- 1:10
-#   attributes(exampleTime)$unit <- "hour"
-#   expect_equal(as.numeric(convertTimeunit(exampleTime)), 1:10 * 3600)
-#
-#   mySim <- simInit()
-#   expect_equal(maxTimeunit(mySim), NA_character_)
-#
-#   st1 <- c("year", "month", "week", "day", "hour", "second")
-#   st2 <- c(st1, paste0(st1, "s"))
-#   expect_equal(st2, spadesTimes())
-#
-#   expect_equal(as.numeric(dNA()), 0)
-#   expect_equal(as.numeric(dhour(1)), 60 * 60)
-#   expect_equal(as.numeric(dday(1)), 60 * 60 * 24)
-#   expect_equal(as.numeric(dweeks(1)), 60 * 60 * 24 * 365.25 / 52)
-#   expect_equal(as.numeric(dweek(1)), 60 * 60 * 24 * 365.25 / 52)
-# })
+test_that("timeunit works correctly", {
+  testInitOut <- testInit()
+  on.exit({
+    testOnExit(testInitOut)
+  }, add = TRUE)
+
+  times <- list(start = 0.0, end = 10)
+  params <- list(
+    .globals = list(burnStats = "npixelsburned", stackName = "landscape"),
+    randomLandscapes = list(.plotInitialTime = NA, .plotInterval = NA),
+    caribouMovement = list(.plotInitialTime = NA, .plotInterval = NA),
+    fireSpread = list(.plotInitialTime = NA, .plotInterval = NA)
+  )
+  modules <- list("randomLandscapes", "caribouMovement", "fireSpread")
+  paths <- list(modulePath = system.file("sampleModules", package = "SpaDES.core"))
+
+  mySim <- simInit(times, params, modules, objects = list(), paths = paths)
+
+  expect_equal(maxTimeunit(sim = mySim), "year")
+
+  x1 <- list(
+    name = "testModule",
+    description = "this is a test.",
+    keywords = c("test"),
+    authors = c(person(c("Alex", "M"), "Chubaty",
+                       email = "alexander.chubaty@canada.ca",
+                       role = c("aut", "cre"))),
+    version = list(testModule = "0.0.1"),
+    spatialExtent = raster::extent(rep(NA_real_, 4)),
+    timeframe = as.POSIXlt(c(NA, NA)),
+    timeunit = NA_character_,
+    citation = list(),
+    reqdPkgs = list("grid", "raster", "sp"),
+    parameters = rbind(
+      defineParameter("dummyVal", "numeric", 1.0, NA, NA, "vague description")
+    ),
+    inputObjects = dplyr::bind_rows(
+      expectsInput(objectName = "testInput", objectClass = "list", sourceURL = "", desc = NA_character_)
+    ),
+    outputObjects = dplyr::bind_rows(
+      createsOutput(objectName = "testOutput", objectClass = "list", desc = NA_character_)
+    )
+  )
+
+  # Test for numerics, or character strings that are not recognized
+  expect_message(timeunit(mySim) <- 1, "^unknown timeunit provided:")
+  expect_message(timeunit(mySim) <- "LeapYear", "^unknown timeunit provided:")
+
+
+  # check for new unit being put into simList
+  assign("dfortnight", function(x) lubridate::duration(dday(14)),
+         envir = envir(mySim))
+  expect_match(timeunit(mySim) <- "fortnight", "")
+  expect_match(timeunit(mySim), "fortnight")
+  expect_equivalent(as.numeric(mySim$dfortnight(1)), 1209600)
+  rm(dfortnight, envir = envir(mySim))
+
+  # test that NA_real_ gets coerced to NA_character_
+  timeunit(mySim) <- NA_real_
+  expect_identical(timeunit(mySim), NA_character_)
+
+  # check that the minTimeunit captures one of the timestepUnits in the loaded modules
+  expect_true(
+    any(match(minTimeunit(mySim),
+              sapply(depends(mySim)@dependencies, function(x) {
+                x@timeunit
+              })
+             )
+       )
+  )
+
+  # check that minTimeunit finds the smallest timeunit of the modules loaded
+  whNotNA <- sapply(depends(mySim)@dependencies,
+                    function(x) !is.na(x@timeunit))
+  expect_equivalent(as.numeric(eval(parse(
+    text = paste0("d", minTimeunit(mySim), "(1)")))),
+    min(sapply(depends(mySim)@dependencies[whNotNA],
+               function(x) {
+                 eval(parse(text = paste0("d", x@timeunit, "(1)")))
+               }
+    )))
+  expect_equal(as.numeric(inSeconds(NA_character_)), 0)
+  expect_equal(as.numeric(inSeconds(NULL)), 0)
+
+  exampleTime <- 1:10
+  attributes(exampleTime)$unit <- NA_character_
+  expect_equal(as.numeric(convertTimeunit(exampleTime, "seconds")),
+               rep(0, length(exampleTime)))
+
+  exampleTime <- 1:10
+  attributes(exampleTime)$unit <- "hour"
+  expect_equal(as.numeric(convertTimeunit(exampleTime)), 1:10 * 3600)
+
+  mySim <- simInit()
+  expect_equal(maxTimeunit(mySim), NA_character_)
+
+  st1 <- c("year", "month", "week", "day", "hour", "second")
+  st2 <- c(st1, paste0(st1, "s"))
+  expect_equal(st2, spadesTimes())
+
+  expect_equal(as.numeric(dNA()), 0)
+  expect_equal(as.numeric(dhour(1)), 60 * 60)
+  expect_equal(as.numeric(dday(1)), 60 * 60 * 24)
+  expect_equal(as.numeric(dweeks(1)), 60 * 60 * 24 * 365.25 / 52)
+  expect_equal(as.numeric(dweek(1)), 60 * 60 * 24 * 365.25 / 52)
+})
 
 test_that("timeunits with child and parent modules work correctly", {
   m <- testInit("igraph", smcc = TRUE)
+  options("spades.memoryUseInterval" = 0)
   on.exit({
     testOnExit(m)
   }, add = TRUE)
@@ -228,11 +229,11 @@ test_that("timeunits with child and parent modules work correctly", {
 
   cacheDir <- file.path(tmpdir, rndstr(1, 6)) %>% checkPath(create = TRUE)
   try(clearCache(cacheDir, ask = FALSE), silent = TRUE)
-  expect_error(
+  expect_error({
     mySim <- simInit(modules = list(modName),
                      paths = list(modulePath = tmpdir, inputPath = tmpdir, cachePath = cacheDir),
                      params = list("child6" = list(.useCache = ".inputObjects")))
-  )
+  })
 
 
   xxx1 <- c(xxx[seq(lineOfInterest1 - 1)], "  expectsInput(\"b\", \"character\", \"temp thing\"),",
@@ -255,19 +256,20 @@ test_that("timeunits with child and parent modules work correctly", {
                    "There is no similar item in the cacheRepo",
                    "child6: using dataPath",
                    sep = "|")
-  expect_silent(expect_message(
-    mySim <- simInit(modules = list(modName),
-                     paths = list(modulePath = tmpdir, inputPath = tmpdir, cachePath = cacheDir),
-                     params = list("child6" = list(.useCache = ".inputObjects"))),
-    msgGrep)
-  )
-
-  # pulls cached value
-  a <- capture.output(mm1 <- capture_messages(
+  expect_silent(expect_message({
     mySim <- simInit(modules = list(modName),
                      paths = list(modulePath = tmpdir, inputPath = tmpdir, cachePath = cacheDir),
                      params = list("child6" = list(.useCache = ".inputObjects")))
-  ))
+  }, msgGrep))
+
+  # pulls cached value
+  a <- capture.output({
+    mm1 <- capture_messages({
+      mySim <- simInit(modules = list(modName),
+                       paths = list(modulePath = tmpdir, inputPath = tmpdir, cachePath = cacheDir),
+                       params = list("child6" = list(.useCache = ".inputObjects")))
+    })
+  })
   mm1 <- cleanMessage(mm1)
   fullMessage <- c(
     "Running .inputObjects for child6",
@@ -280,22 +282,26 @@ test_that("timeunits with child and parent modules work correctly", {
   # Change the file that is in the arguments to .inputObjects
   write.table(x = data.frame(sample(1e6, 1)), file = theFile)
   # Cache should force a rerun -- i.e., not cached value
-  a <- capture.output(mm1 <- capture_messages(
-    mySim <- simInit(modules = list(modName),
-                     paths = list(modulePath = tmpdir, inputPath = tmpdir, cachePath = cacheDir),
-                     params = list("child6" = list(.useCache = ".inputObjects")))))
+  a <- capture.output({
+    mm1 <- capture_messages({
+      mySim <- simInit(modules = list(modName),
+                       paths = list(modulePath = tmpdir, inputPath = tmpdir, cachePath = cacheDir),
+                       params = list("child6" = list(.useCache = ".inputObjects")))
+      })
+    })
 
   mm1 <- cleanMessage(mm1)
   expect_true(all(unlist(lapply(fullMessage, function(x) any(grepl(mm1, pattern = x))))))
 
   # pulls cached value
-  a <- capture.output(mm1 <- capture_messages(
-    mySim <- simInit(modules = list(modName),
-                     paths = list(modulePath = tmpdir, inputPath = tmpdir, cachePath = cacheDir),
-                     params = list("child6" = list(.useCache = ".inputObjects")))
-  ))
+  a <- capture.output({
+    mm1 <- capture_messages({
+      mySim <- simInit(modules = list(modName),
+                       paths = list(modulePath = tmpdir, inputPath = tmpdir, cachePath = cacheDir),
+                       params = list("child6" = list(.useCache = ".inputObjects")))
+    })
+  })
   mm1 <- cleanMessage(mm1)
-  expect_true(all(unlist(lapply(fullMessage,
-                                function(x) any(grepl(mm1, pattern = x))))))
+  expect_true(all(unlist(lapply(fullMessage, function(x) any(grepl(mm1, pattern = x))))))
   expect_true(any(grepl("Running .inputObjects", mm1)))
 })
